@@ -8,7 +8,7 @@ This is a shortcut to `modify-node-metadata` that allows for removing a single
 key OR all keys in a simpler form.
   EOT
 
-  example <<-EOT
+  example api: <<-EOT
 Remove a single key from a node:
 
     {"node": "node1", "key": "my_key"}
@@ -18,11 +18,21 @@ or remove all keys from a node:
     {"node": "node1", "all": true}
   EOT
 
+  example cli: <<-EOT
+Remove a single key from a node:
+
+    razor remove-node-metadata --node node1 --key my_key
+
+or remove all keys from a node:
+
+    razor remove-node-metadata --node node1 --all
+  EOT
+
 
   authz '%{node}'
 
   attr 'node', type: String, required: true, references: [Razor::Data::Node, :name],
-               help: _('The node to remove metadata from')
+               help: _('The node from which to remove metadata')
 
   attr 'key', type: String, size: 1..Float::INFINITY,
               help: _('The name of the metadata item to remove from the node.')
