@@ -133,13 +133,14 @@ module Razor::Data
 
     # Retrieve the entire log for this node as an array of hashes, ordered
     # by increasing timestamp. In addition to the keys mentioned for
-    # +log_append+ each entry will also contain the +timstamp+ in ISO8601
+    # +log_append+ each entry will also contain the +timestamp+ in ISO8601
     # format
     def log(params = {})
       cursor = Razor::Data::Event.order(:timestamp).order(:id).reverse.
           where(node_id: id).limit(params[:limit], params[:start])
       cursor.map do |log|
-        { 'timestamp' => log.timestamp.xmlschema }.update(log.entry)
+        { 'timestamp' => log.timestamp.xmlschema,
+          'severity' => log.severity, }.update(log.entry)
       end
     end
 
@@ -212,14 +213,14 @@ module Razor::Data
         modify_metadata('no_replace' => true, 'update' => policy.node_metadata)
       end
 
-      Razor::Data::Hook.run('node-bound-to-policy', node: self, policy: policy)
+      Razor::Data::Hook.trigger('node-bound-to-policy', node: self, policy: policy)
 
       self
     end
 
     def unbind
+      Razor::Data::Hook.trigger('node-unbound-from-policy', node: self, policy: self.policy)
       self.policy = nil
-      Razor::Data::Hook.run('node-unbound-from-policy', node: self)
     end
 
     # This is a hack around the fact that the auto_validates plugin does
@@ -331,7 +332,7 @@ module Razor::Data
       end
       if facts != new_facts
         self.facts = new_facts
-        Razor::Data::Hook.run('node-facts-changed', node: self)
+        Razor::Data::Hook.trigger('node-facts-changed', node: self)
       end
       # @todo lutter 2013-09-09: we'd really like to use the DB's idea of
       # time, i.e. have the update statement do 'last_checkin = now()' but
@@ -431,7 +432,7 @@ module Razor::Data
 
     def destroy
       super
-      Razor::Data::Hook.run('node-deleted', node: self)
+      Razor::Data::Hook.trigger('node-deleted', node: self)
     end
 
     # Use the facts +facts+ to fully register the node; this is a
@@ -481,7 +482,7 @@ module Razor::Data
           kill_node.destroy
         end
         keep_node.save
-        Razor::Data::Hook.run('node-registered', node: keep_node)
+        Razor::Data::Hook.trigger('node-registered', node: keep_node)
         keep_node
       end
     end
@@ -493,7 +494,7 @@ module Razor::Data
       node.boot_count += 1
       if name == "finished" and node.policy
         node.installed = node.policy.name
-        Razor::Data::Hook.run('node-install-finished', node: node)
+        Razor::Data::Hook.trigger('node-install-finished', node: node)
       end
       node.save
     end
