@@ -83,6 +83,14 @@ file; on this server security is currently <%= auth %>.
     path.empty? and _('the command') or path
   end
 
+  # The validation for this class is roughly:
+  # - Fundamental type validation
+  # - Checking authz
+  # - Running alias mutation
+  # - Running user-supplied `conform!`
+  # - Checking existing attributes
+  # - Checking `require_one_of`
+  # - Checking for additional attributes
   def validate!(data, path)
     checked = {}
 
@@ -124,6 +132,26 @@ at https://tickets.puppetlabs.com/
       org.apache.shiro.SecurityUtils.subject.check_permissions(authz)
     end
 
+    # Run the aliases for the command.
+    apply_aliases!(data)
+
+    # Run the user-supplied `conform!` method. This will perform various
+    # mutations that must occur before we perform the attribute validation.
+    # This is passed as a block because the method itself is on the command.
+    if block_given?
+      old_data = data.to_json
+      data = yield data
+      # Sanity check that the user-supplied `conform!` method indeed returns the
+      # correct datatype.
+      unless data.class <= Hash
+        raise _(<<-ERR) % {class: self.class, type: data.class, body: old_data.inspect}
+Internal error: Please report this to JIRA at http://jira.puppetlabs.com/
+`%{class}.conform!` returned unexpected class %{type} instead of Hash
+Body is: '%{body}'
+        ERR
+      end
+    end
+
     # Now, check any remaining attributes.
     @attributes.each do |attr, check|
       next if checked[attr]
@@ -166,6 +194,49 @@ at https://tickets.puppetlabs.com/
     end
   end
 
+  def apply_aliases!(data)
+    # Run through the list of aliases for each attribute, which will perform
+    # the proper reassignment for future steps.
+    @attributes.each do |attr, check|
+      check.aliases && check.aliases.each do |aliaz|
+        data = run_alias(data, aliaz, attr)
+      end
+    end
+    data
+  end
+
+  # This adds an alias between two attributes. If a block is provided, it will
+  # be used to combine the attributes in the case that both exist. If no block
+  # is provided, only one of the attributes can be supplied, else an error is
+  # thrown. When the alias operation completes, the alias will be removed from
+  # the `data` hash.
+  def run_alias(data, alias_name, real_attribute)
+    real = data[real_attribute]
+    aliaz = data[alias_name]
+    # Only matters if the alias is provided.
+    if aliaz
+      data[real_attribute] =
+          if real
+            # Merge the data.
+            if block_given?
+              yield(aliaz, real)
+            elsif aliaz.is_a?(Array) and real.is_a?(Array)
+              # Easy to combine Arrays.
+              (real + aliaz).uniq
+            elsif aliaz.is_a?(Hash) and real.is_a?(Hash)
+              # Easy to combine Hashes.
+              real.merge(aliaz)
+            else
+              raise Razor::ValidationFailure.new("cannot supply both #{real_attribute} and #{alias_name}")
+            end
+          else
+            data[alias_name]
+          end
+      data.delete(alias_name)
+    end
+    data
+  end
+
   def to_json(arg)
     @attributes.to_json
   end
@@ -201,6 +272,7 @@ at https://tickets.puppetlabs.com/
 
   def attr(name, checks = {})
     name.is_a?(String) or raise ArgumentError, "attribute name must be a string"
+    # Add '-' alias(es) if applicable.
     @attributes[name] = Razor::Validation::HashAttribute.new(name, checks)
   end
 
